@@ -1,4 +1,5 @@
 package Dancer2::Plugin::PageHistory;
+use utf8;
 
 =head1 NAME
 
@@ -6,11 +7,11 @@ Dancer2::Plugin::PageHistory - store recent page history for user into session
 
 =head1 VERSION
 
-Version 0.202
+Version 0.203
 
 =cut
 
-our $VERSION = '0.202';
+our $VERSION = '0.203';
 
 use Dancer2::Core::Types qw/Bool HashRef Str/;
 use Dancer2::Plugin;
@@ -230,6 +231,10 @@ sub history {
 
 Peter Mottram (SysPete), C<< <peter@sysnix.com> >>
 
+=head1 CONTRIBUTORS
+
+Slaven Rezić (eserte) - GH issue #1
+
 =head1 BUGS
 
 Please report any bugs or feature requests via the project's GitHub
